@@ -292,6 +292,11 @@ double* FstTable::GetDoubleWriter(unsigned int colNr)
 }
 
 
+IByteBlockColumn* FstTable::GetByteBlockWriter(unsigned int col_nr){
+  return nullptr;
+}
+
+
 IStringWriter* FstTable::GetStringWriter(unsigned int colNr)
 {
   cols = VECTOR_ELT(*rTable, colNr);  // retrieve column vector
@@ -444,6 +449,13 @@ void FstTable::SetDoubleColumn(IDoubleColumn* doubleColumn, int colNr)
 }
 
 
+IByteBlockColumn* FstTable::add_byte_block_column(unsigned col_nr)
+{
+  // to be implemented
+  return nullptr;
+}
+
+
 void FstTable::SetIntegerColumn(IIntegerColumn* integerColumn, int colNr)
 {
   IntegerColumn* iColumn = (IntegerColumn*) integerColumn;
