@@ -27,6 +27,7 @@
 
 #include "ifstcolumn.h"
 #include "istringwriter.h"
+#include "ibyteblockcolumn.h"
 
 
 /**
@@ -41,19 +42,21 @@ class IFstTable
     virtual FstColumnType ColumnType(unsigned int colNr, FstColumnAttribute &columnAttribute, short int &scale,
       std::string &annotation, bool &hasAnnotation) = 0;
 
-	// Writer interface
+  // Writer interface
     virtual IStringWriter* GetStringWriter(unsigned int colNr) = 0;
 
     virtual int* GetLogicalWriter(unsigned int colNr) = 0;
 
     virtual int* GetIntWriter(unsigned int colNr) = 0;
 
-  	virtual long long* GetInt64Writer(unsigned int colNr) = 0;
+    virtual long long* GetInt64Writer(unsigned int colNr) = 0;
 
     virtual char* GetByteWriter(unsigned int colNr) = 0;
 
     virtual double* GetDoubleWriter(unsigned int colNr) = 0;
 
+    virtual IByteBlockColumn* GetByteBlockWriter(unsigned int col_nr) = 0;
+
     virtual IStringWriter* GetLevelWriter(unsigned int colNr) = 0;
 
     virtual IStringWriter* GetColNameWriter() = 0;
@@ -66,27 +69,29 @@ class IFstTable
 
     virtual unsigned long long NrOfRows() = 0;
 
-	// Reader interface
-  	virtual void InitTable(unsigned int nrOfCols, unsigned long long nrOfRows) = 0;
+	  // Reader interface
+    virtual void InitTable(unsigned int nrOfCols, unsigned long long nrOfRows) = 0;
 
-  	virtual void SetStringColumn(IStringColumn* stringColumn, int colNr) = 0;
+    virtual IByteBlockColumn* add_byte_block_column(unsigned col_nr) = 0;
 
-  	virtual void SetLogicalColumn(ILogicalColumn* logicalColumn, int colNr) = 0;
+    virtual void SetStringColumn(IStringColumn* stringColumn, int colNr) = 0;
+
+    virtual void SetLogicalColumn(ILogicalColumn* logicalColumn, int colNr) = 0;
 
     virtual void SetIntegerColumn(IIntegerColumn* integerColumn, int colNr) = 0;
 
-  	virtual void SetDoubleColumn(IDoubleColumn* doubleColumn, int colNr) = 0;
+    virtual void SetDoubleColumn(IDoubleColumn* doubleColumn, int colNr) = 0;
 
-  	virtual void SetFactorColumn(IFactorColumn* factorColumn, int colNr) = 0;
+    virtual void SetFactorColumn(IFactorColumn* factorColumn, int colNr) = 0;
 
-  	virtual void SetInt64Column(IInt64Column* int64Column, int colNr) = 0;
+    virtual void SetInt64Column(IInt64Column* int64Column, int colNr) = 0;
 
-  	virtual void SetByteColumn(IByteColumn* byteColumn, int colNr) = 0;
+    virtual void SetByteColumn(IByteColumn* byteColumn, int colNr) = 0;
 
-  	// use more efficient string container here (e.g. std::vector<string>)
-  	virtual void SetColNames(IStringArray* col_names) = 0;
+    // use more efficient string container here (e.g. std::vector<string>)
+    virtual void SetColNames(IStringArray* col_names) = 0;
 
-  	virtual void SetKeyColumns(int* keyColPos, unsigned int nrOfKeys) = 0;
+    virtual void SetKeyColumns(int* keyColPos, unsigned int nrOfKeys) = 0;
 };
 
 #endif  // IFST_TABLE_H
