@@ -1,7 +1,6 @@
 
 context("integer64 column")
 
-library(bit64)
 library(data.table)
 
 # Clean testdata directory
@@ -11,13 +10,18 @@ if (!file.exists("testdata")) {
   file.remove(list.files("testdata", full.names = TRUE))
 }
 
-
 # Prepare example
-dtint64 <- data.frame(
-  Int64 = as.integer64(sample(c(2345612345679, 1234567890, 8714567890), 100, replace = TRUE)))
+if (requireNamespace("bit64", quietly = TRUE)) {
+  dtint64 <- data.frame(
+    Int64 = bit64::as.integer64(sample(c(2345612345679, 1234567890, 8714567890), 100, replace = TRUE))
+  )
+}
 
 
 test_that("Type integer64 issue #28", {
+
+  skip_if_not(requireNamespace("bit64", quietly = TRUE))
+
   expect_equal(class(dtint64$Int64), "integer64")
 
   # Write to fst
@@ -33,6 +37,9 @@ test_that("Type integer64 issue #28", {
 
 
 test_that("Type integer64 with compression", {
+
+  skip_if_not(requireNamespace("bit64", quietly = TRUE))
+
   # Write to fst
   fstwriteproxy(dtint64, "testdata/dt_int64.fst", 95)
 
@@ -46,6 +53,8 @@ test_that("Type integer64 with compression", {
 
 test_that("Type integer64 with compression as data.table", {
 
+  skip_if_not(requireNamespace("bit64", quietly = TRUE))
+
   setDT(dtint64)
   fstwriteproxy(dtint64, "testdata/dt_int64.fst", 95)  # Write to fst
 
