@@ -16,21 +16,21 @@ setkey(x, A, B, D)
 
 test_that("Fully keyed table", {
   fstwriteproxy(x, "testdata/keys.fst")
-  y <- fstreadproxy("testdata/keys.fst", as.data.table = TRUE)
+  y <- fstreadproxy("testdata/keys.fst", as_data_table = TRUE)
   expect_equal(key(y), key(x))
 })
 
 
 test_that("Missing last key", {
   fstwriteproxy(x, "testdata/keys.fst")
-  y <- fstreadproxy("testdata/keys.fst", columns = c("A", "B", "C", "E"), as.data.table = TRUE)
+  y <- fstreadproxy("testdata/keys.fst", columns = c("A", "B", "C", "E"), as_data_table = TRUE)
   expect_equal(key(y), c("A", "B"))
 })
 
 
 test_that("Missing middle key", {
   fstwriteproxy(x, "testdata/keys.fst")
-  y <- fstreadproxy("testdata/keys.fst", columns = c("A", "C", "D", "E"), as.data.table = TRUE)
+  y <- fstreadproxy("testdata/keys.fst", columns = c("A", "C", "D", "E"), as_data_table = TRUE)
   expect_equal(key(y), c("A"))
 })
 
@@ -38,6 +38,6 @@ test_that("Missing middle key", {
 test_that("Missing first key", {
   fstwriteproxy(x, "testdata/keys.fst")
   res <- fst:::fstretrieve("testdata/keys.fst", c("B", "C", "D", "E"), 1L, NULL)
-  y <- fstreadproxy("testdata/keys.fst", columns = c("B", "C", "D", "E"), as.data.table = TRUE)
+  y <- fstreadproxy("testdata/keys.fst", columns = c("B", "C", "D", "E"), as_data_table = TRUE)
   expect_null(key(y))
 })
